@@ -4,7 +4,7 @@ from typing import TYPE_CHECKING, Any, Dict, Iterator
 from ..base import PRAWBase
 
 if TYPE_CHECKING:  # pragma: no cover
-    from .... import praw
+    import praw
 
 
 class BaseList(PRAWBase):
