@@ -83,7 +83,7 @@ class Reddit:
     """
 
     update_checked = False
-    _ratelimit_regex = re.compile(r"([0-9]{1,2}) (seconds?|minutes?)")
+    _ratelimit_regex = re.compile(r"([0-9]{1,3}) (milliseconds?|seconds?|minutes?)")
 
     @property
     def _next_unique(self) -> int:
@@ -271,6 +271,25 @@ class Reddit:
 
         """
 
+        self.drafts = models.DraftHelper(self, None)
+        """An instance of :class:`.DraftHelper`.
+
+        Provides the interface for working with :class:`.Draft` instances.
+
+        For example, to list the currently authenticated user's drafts:
+
+        .. code-block:: python
+
+            drafts = reddit.drafts()
+
+        To create a draft on r/redditdev run:
+
+        .. code-block:: python
+
+            reddit.drafts.create(title="title", selftext="selftext", subreddit="redditdev")
+
+        """
+
         self.front = models.Front(self)
         """An instance of :class:`.Front`.
 
@@ -458,6 +477,8 @@ class Reddit:
             self.config.kinds["trophy"]: models.Trophy,
             "Button": models.Button,
             "Collection": models.Collection,
+            "Draft": models.Draft,
+            "DraftList": models.DraftList,
             "Image": models.Image,
             "LabeledMulti": models.Multireddit,
             "Listing": models.Listing,
@@ -471,6 +492,7 @@ class Reddit:
             "Submenu": models.Submenu,
             "TrophyList": models.TrophyList,
             "UserList": models.RedditorList,
+            "UserSubreddit": models.UserSubreddit,
             "button": models.ButtonWidget,
             "calendar": models.Calendar,
             "community-list": models.CommunityList,
@@ -690,10 +712,12 @@ class Reddit:
                 if not amount_search:
                     break
                 seconds = int(amount_search.group(1))
-                if "minute" in amount_search.group(2):
+                if amount_search.group(2).startswith("minute"):
                     seconds *= 60
+                elif amount_search.group(2).startswith("millisecond"):
+                    seconds = 0
                 if seconds <= int(self.config.ratelimit_seconds):
-                    sleep_seconds = seconds + min(seconds / 10, 1)
+                    sleep_seconds = seconds + 1
                     return sleep_seconds
         return None
 
@@ -702,6 +726,7 @@ class Reddit:
         path: str,
         data: Optional[Union[Dict[str, Union[str, Any]], bytes, IO, str]] = None,
         json=None,
+        params: Optional[Union[str, Dict[str, str]]] = None,
     ) -> Any:
         """Return parsed objects returned from a DELETE request to ``path``.
 
@@ -711,9 +736,12 @@ class Reddit:
         :param json: JSON-serializable object to send in the body of the request with a
             Content-Type header of application/json (default: None). If ``json`` is
             provided, ``data`` should not be.
+        :param params: The query parameters to add to the request (default: None).
 
         """
-        return self._objectify_request(data=data, json=json, method="DELETE", path=path)
+        return self._objectify_request(
+            data=data, json=json, method="DELETE", params=params, path=path
+        )
 
     def patch(
         self,
@@ -756,28 +784,29 @@ class Reddit:
         """
         if json is None:
             data = data or {}
-        try:
-            return self._objectify_request(
-                data=data,
-                files=files,
-                json=json,
-                method="POST",
-                params=params,
-                path=path,
-            )
-        except RedditAPIException as exception:
-            seconds = self._handle_rate_limit(exception=exception)
-            if seconds is not None:
-                logger.debug(f"Rate limit hit, sleeping for {seconds:.2f} seconds")
-                time.sleep(seconds)
+
+        attempts = 3
+        last_exception = None
+        while attempts > 0:
+            attempts -= 1
+            try:
                 return self._objectify_request(
                     data=data,
                     files=files,
+                    json=json,
                     method="POST",
                     params=params,
                     path=path,
                 )
-            raise
+            except RedditAPIException as exception:
+                last_exception = exception
+                seconds = self._handle_rate_limit(exception=exception)
+                if seconds is None:
+                    break
+                second_string = "second" if seconds == 1 else "seconds"
+                logger.debug(f"Rate limit hit, sleeping for {seconds} {second_string}")
+                time.sleep(seconds)
+        raise last_exception
 
     def put(
         self,
